@@ -1,5 +1,5 @@
 import json
-import time
+import time, re
 from collections import namedtuple
 from ixnetwork_restpy import TestPlatform, SessionAssistant
 import snappi
@@ -285,6 +285,30 @@ class Api(snappi.Api):
         else:
             self._errors.append(error)
 
+    def parse_location_info(self, location):
+        """It will return (chassis,card,port)
+        set card as 0 where that is not applicable"""
+        if re.search("/|;", location) is None:
+            raise Exception("Invalid port location format, expected ["
+                    "chassis_ip;card_id;port_id or chassis_ip/port_id]")
+        LocationInfo = namedtuple("LocationInfo", ["chassis_info",
+                                                   "card_info",
+                                                   "port_info"])
+        if ';' in location:
+            try:
+                (chassis_info, card_info, port_info) = location.split(';')
+            except Exception:
+                raise Exception("Please specify <chassis>;<card>;<port>")
+        else:
+            try:
+                card_info = 0
+                (chassis_info, port_info) = location.split('/')
+            except Exception:
+                raise Exception("Please specify <chassis>/<port>")
+        return LocationInfo(chassis_info,
+                        card_info,
+                        port_info)
+    
     def _connect(self):
         """Connect to an IxNetwork API Server.
         """
@@ -314,14 +338,26 @@ class Api(snappi.Api):
                 self._ixnetwork.Globals.Licensing \
                     .LicensingServers = self._license_servers
             try:
-                version = pkg_resources.get_distribution(
-                    "snappi_ixnetwork").version
-            except Exception:
-                version = "snappi_ixnetwork not installed " \
-                    "using pip, unable to determine version"
-            self.info(version)
+                import pkg_resources
+                snappi_ver = "snappi-" +\
+                    pkg_resources.get_distribution("snappi").version
+                self.info(snappi_ver)
+                snappi_ixn = "snappi_ixnetwork-" +\
+                    pkg_resources.get_distribution("snappi_ixnetwork").version
+                self.info(snappi_ixn)
+                restpy = "ixnetwork_restpy-" + pkg_resources.get_distribution(
+                    "ixnetwork_restpy"
+                ).version
+                self.info(restpy)
+            except pkg_resources.DistributionNotFound as e:
+                version = "Could not determine version for pkg {}".format(
+                    e.req.project_name
+                )
+                self.info(version)
+            except Exception as e:
+                self.warning('{}'.format(e))
         self._backup_errors()
-    
+
     def _backup_errors(self):
         app_errors = self._globals.AppErrors.find()
         if len(app_errors) > 0:
